summaryrefslogtreecommitdiffstats
path: root/glpi-localdef.patch
blob: 7b7be8d461360b6b9534fc0ceeabf1cfe9d03f4c (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
diff -up ./inc/based_config.php.rpm ./inc/based_config.php
--- ./inc/based_config.php.rpm	2017-10-11 09:59:42.446010854 +0200
+++ ./inc/based_config.php	2017-10-11 10:11:47.457934585 +0200
@@ -46,9 +46,9 @@ if (!empty($tz)) {
    date_default_timezone_set(@date_default_timezone_get());
 }
 
-// If this file exists, it is load
-if (file_exists(GLPI_ROOT. '/config/local_define.php')) {
-   require_once GLPI_ROOT. '/config/local_define.php';
+// If this file exists, it is load from etc (RPM specific)
+if (file_exists('/etc/glpi/local_define.php')) {
+   require_once '/etc/glpi/local_define.php';
 }
 
 // If this file exists, it is load, allow to set configdir/dumpdir elsewhere